@@ -17,4 +17,4 @@
 # along with PyCogWorks.  If not, see <http://www.gnu.org/licenses/>.
 #===============================================================================
 
-from logging import get_time, getTime, getDateTimeStamp, writeHistoryFile
\ No newline at end of file
+from logging import get_time, getTime, getDateTimeStamp, writeHistoryFile, Logger
\ No newline at end of file
